cmd

package
v0.0.0-...-8a2579a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2023 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Copyright © 2023 Flavio Silva flavio1110@gmaill.com

Copyright © 2023 Flavio Silva flavio1110@gmaill.com

Copyright © 2023 Flavio Silva flavio1110@gmaill.com

Copyright © 2023 Flavio Silva flavio1110@gmaill.com

Copyright © 2023 Flavio Silva flavio1110@gmail.com

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright © 2023 Flavio Silva flavio1110@gmail.com

Index

Constants

This section is empty.

Variables

var Blue = "\033[34m"
var Cyan = "\033[36m"
var Gray = "\033[37m"
var Green = "\033[32m"
var Purple = "\033[35m"
var Red = "\033[31m"
var Reset = "\033[0m"
var White = "\033[97m"
var Yellow = "\033[33m"

Functions

func Execute

func Execute()

Types

This section is empty.

Jump to